summaryrefslogtreecommitdiff
path: root/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
diff options
context:
space:
mode:
authorClaudius "keldu" Holeksa <mail@keldu.de>2026-08-13 13:11:05 +0200
committerClaudius "keldu" Holeksa <mail@keldu.de>2026-08-13 13:11:05 +0200
commit7220084ddae1f4c6007f5111913cb7f87a794657 (patch)
treeab118dcda72d3fc85fb8087617705d76b647f62d /examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
parent919f5a625c5efeea94c0dd0de5039a27e77d3fac (diff)
downloadlibs-lbm-7220084ddae1f4c6007f5111913cb7f87a794657.tar.gz
Renaming velocity to momentum. for now
Diffstat (limited to 'examples/poiseulle_particles_2d_ibm_gpu/sim.cpp')
-rw-r--r--examples/poiseulle_particles_2d_ibm_gpu/sim.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp b/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
index 640c9ab..d63515d 100644
--- a/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
+++ b/examples/poiseulle_particles_2d_ibm_gpu/sim.cpp
@@ -46,7 +46,7 @@ using RhoChunk = Chunk<Scalar<T>, 0u, dim_x, dim_y>;
template<typename T, typename Desc>
using MacroStruct = Struct<
- Member<VelChunk<T,Desc>, "velocity">,
+ Member<VelChunk<T,Desc>, "momentum">,
Member<RhoChunk<T>, "density">,
Member<VelChunk<T,Desc>, "force">
>;
@@ -113,7 +113,7 @@ saw::error_or<void> setup_initial_conditions(
//
auto& df_f = fields.template get<"dfs_old">();
auto& rho_f = macros.template get<"density">();
- auto& vel_f = macros.template get<"velocity">();
+ auto& vel_f = macros.template get<"momentum">();
auto& force_f = macros.template get<"force">();
iterator<Desc::D>::apply(
@@ -218,7 +218,7 @@ saw::error_or<void> step(
q.submit([&](acpp::sycl::handler& h){
h.parallel_for(acpp::sycl::range<1u>{1u}, [=](acpp::sycl::id<1u> idx){
- auto& vel_f = macros.template get<"velocity">();
+ auto& vel_f = macros.template get<"momentum">();
auto& dense_f = macros.template get<"density">();
auto& ps = particles;